@@ -423,7 +423,7 @@ e_filename_make_safe (gchar *string)
 	g_return_if_fail (string != NULL);
 	
 	for (p = string; *p; p++) {
-		if (!isprint ((unsigned char)*p) || strchr (" /'\"`&();|<>${}!", *p))
+		if (!isprint ((unsigned char)*p) || strchr (" /'\"`&();|<>$%{}!", *p))
 			*p = '_';
 	}
 }
@@ -768,6 +768,27 @@ size_t e_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
 #endif
 }
 
+size_t 
+e_utf8_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
+{
+	size_t sz;
+	char *locale_fmt = g_locale_from_utf8(fmt, -1, NULL, &sz, NULL);
+	size_t ret = e_strftime(s, max, locale_fmt, tm);
+	char *buf = g_locale_to_utf8(s, ret, NULL, &sz, NULL);
+	if (sz >= max) {
+		char *tmp = buf + max - 1;
+		tmp = g_utf8_find_prev_char(buf, tmp);
+		if (tmp)
+			sz = tmp - buf;
+		else
+			sz = 0;
+	}
+	memcpy(s, buf, sz);
+	s[sz] = '\0';
+	g_free(locale_fmt);
+	g_free(buf);
+	return sz;
+}
 
 /**
  * Function to do a last minute fixup of the AM/PM stuff if the locale
@@ -830,6 +851,28 @@ size_t e_strftime_fix_am_pm(char *s, size_t max, const char *fmt, const struct t
 	return(ret);
 }
 
+size_t 
+e_utf8_strftime_fix_am_pm(char *s, size_t max, const char *fmt, const struct tm *tm)
+{
+	size_t sz;
+	char *locale_fmt = g_locale_from_utf8(fmt, -1, NULL, &sz, NULL);
+	size_t ret = e_strftime_fix_am_pm(s, max, locale_fmt, tm);
+	char *buf = g_locale_to_utf8(s, ret, NULL, &sz, NULL);
+	if (sz >= max) {
+		char *tmp = buf + max - 1;
+		tmp = g_utf8_find_prev_char(buf, tmp);
+		if (tmp)
+			sz = tmp - buf;
+		else
+			sz = 0;
+	}
+	memcpy(s, buf, sz);
+	s[sz] = '\0';
+	g_free(locale_fmt);
+	g_free(buf);
+	return sz;
+}
+
 /**
  * e_flexible_strtod:
  * @nptr:    the string to convert to a numeric value.
@@ -1140,11 +1183,11 @@ e_gettext (const char *msgid)
 	static gboolean initialized = FALSE;
 
 	if (!initialized) {
-		bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-		bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+		bindtextdomain (E_I18N_DOMAIN, GNOMELOCALEDIR);
+		bind_textdomain_codeset (E_I18N_DOMAIN, "UTF-8");
 		initialized = TRUE;
 	}        
 
-	return dgettext (GETTEXT_PACKAGE, msgid);
+	return dgettext (E_I18N_DOMAIN, msgid);
 }
 
